package com.jclark.xml.parse;

import java.io.IOException;
import java.util.Locale;

/**
 * Default implementation of the <code>Parser</code> interface.
 */
public class ParserImpl implements Parser {
  private EntityManager entityManager = new EntityManagerImpl();
  private Application application = new ApplicationImpl();
  private Locale locale = Locale.getDefault();
  
  public void setEntityManager(EntityManager entityManager) {
    if (entityManager == null)
      throw new NullPointerException();
    this.entityManager = entityManager;
  }

  public void setApplication(Application application) {
    if (application == null)
      throw new NullPointerException();
    this.application = application;
  }

  public void setLocale(Locale locale) {
    if (locale == null)
      throw new NullPointerException();
    this.locale = locale;
  }

  /**
   * Parses an XML document.
   * If no <code>EntityManager</code> has been specified with
   * <code>setEntityManager</code>, then <code>EntityManagerImpl</code>
   * will be used.
   *
   * @param entity the document entity of the XML document
   * @exception NotWellFormedException if the document is not well-formed
   * @exception IOException if an IO error occurs
   * @see EntityManagerImpl
   */
  public void parseDocument(OpenEntity entity) throws IOException {
    new EntityParser(entity, entityManager, application, locale, null)
      .parseDocumentEntity();
  }

}
